@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afuser.c,v 1.2 1999/06/08 19:47:31 bazsi Exp $
+ * $Id: afuser.c,v 1.3 1999/08/04 21:30:53 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -57,11 +57,18 @@ static void do_handle_afuser_log(struct log_handler *c, struct log_info *msg)
 
 	msg_line = c_format("%S %S %S\n", msg->date, msg->host, msg->msg);
 	while ((ut = getutent())) {
+#if !HAVE_MODERN_UTMP
+		if ((self->username->length == 1 && 
+		     self->username->data[0] == '*') ||
+		    (self->username->length == strlen(ut->ut_name) &&
+		     memcmp(self->username->data, ut->ut_name, self->username->length) == 0)) {
+#else
 		if (ut->ut_type == USER_PROCESS &&
 		    ((self->username->length == 1 && 
 		      self->username->data[0] == '*') ||
 		     (self->username->length == strlen(ut->ut_user) &&
 		      memcmp(self->username->data, ut->ut_user, self->username->length) == 0))) {
+#endif
 			char line[128];
 			int fd;
 
