@@ -1,6 +1,6 @@
 
 /*  A Bison parser, made from cfg-grammar.y
- by  GNU Bison version 1.25.90
+ by  GNU Bison version 1.27
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -435,7 +435,7 @@ static const short yycheck[] = {     2,
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
 #line 3 "/usr/share/misc/bison.simple"
-/* This file comes from bison-1.25.90.  */
+/* This file comes from bison-1.27.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -452,7 +452,8 @@ static const short yycheck[] = {     2,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -1351,7 +1352,7 @@ case 105:
     break;}
 case 106:
 #line 436 "cfg-grammar.y"
-{ yyval.node = yyvsp[0].node; ;
+{ yyval.node = yyvsp[0].node; if (!yyvsp[0].node) return 1; ;
     break;}
 case 107:
 #line 437 "cfg-grammar.y"
