@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: filters.c,v 1.7 1999/05/26 09:17:56 bazsi Exp $
+ * $Id: filters.c,v 1.8 1999/07/22 09:36:08 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -151,6 +151,20 @@ static void free_regexp(regex_t *re)
 	regfree(re);
 }
 
+static int compile_regex(const char *re, regex_t *regex)
+{
+	int regerr;
+	regerr = regcomp(regex, re, REG_NOSUB | REG_EXTENDED);
+	if (regerr) {
+		char errorbuf[256];
+
+		regerror(regerr, regex, errorbuf, sizeof(errorbuf));
+		werror("Error compiling regular expression: \"%z\" (%z)\n", re, errorbuf);
+		return 0;
+	}
+	return 1;
+}
+
 static int do_filter_host(struct filter_expr_node *c, struct log_info *log)
 {
 	CAST(filter_expr_re, self, c);
@@ -160,8 +174,12 @@ static int do_filter_host(struct filter_expr_node *c, struct log_info *log)
 struct filter_expr_node *make_filter_host(const char *re)
 {
 	NEW(filter_expr_re, self);
+
 	self->super.eval = do_filter_host;
-	regcomp(&self->regex, re, REG_NOSUB | REG_EXTENDED);
+	if (!compile_regex(re, &self->regex)) {
+		KILL(self);
+		return NULL;
+	}
 	return &self->super;
 }
 
@@ -174,8 +192,13 @@ static int do_filter_match(struct filter_expr_node *c, struct log_info *log)
 struct filter_expr_node *make_filter_match(const char *re)
 {
 	NEW(filter_expr_re, self);
+
 	self->super.eval = do_filter_match;
-	regcomp(&self->regex, re, REG_NOSUB | REG_EXTENDED);
+	if (!compile_regex(re, &self->regex)) {
+		KILL(self);
+		return NULL;
+	}
+
 	return &self->super;
 }
 
@@ -188,7 +211,12 @@ static int do_filter_prog(struct filter_expr_node *c, struct log_info *log)
 struct filter_expr_node *make_filter_prog(const char *re)
 {
 	NEW(filter_expr_re, self);
+
 	self->super.eval = do_filter_prog;
-	regcomp(&self->regex, re, REG_NOSUB | REG_EXTENDED);
+	if (!compile_regex(re, &self->regex)) {
+		KILL(self);
+		return NULL;
+	}
+
 	return &self->super;
 }
