@@ -118,10 +118,15 @@ void sig_term(int signo)
 
 int main_loop(struct syslog_backend *backend)
 {
+	int exit_main_loop = 0;
+
 	signal(SIGPIPE, SIG_IGN);
 	signal(SIGHUP, sig_hup);
+	signal(SIGTERM, sig_term);
 
 	while (io_iter(&backend->super)) {
+		if (exit_main_loop)
+			break;
 		if (sighuprecvd) {
 
 			notice("SIGHUP received, restarting syslog-ng\n");
@@ -139,9 +144,9 @@ int main_loop(struct syslog_backend *backend)
 			sighuprecvd = 0;
 		}
 		if (sigtermrecvd) {
-			notice("syslog-ng version %z exiting\n", VERSION);
+			notice("syslog-ng version %z going down\n", VERSION);
 			CONFIG_DESTROY(backend->configuration);
-			break;
+			exit_main_loop = 1;
 		}
 	}
 	return 0;
