@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: utils.c,v 1.7 1999/07/10 15:58:33 bazsi Exp $
+ * $Id: utils.c,v 1.8 1999/08/04 21:30:53 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -47,7 +47,7 @@ char *getshorthostname(char *buf, size_t bufsize)
         return buf;
 }
 
-#ifndef HAVE_INET_ATON
+#if !HAVE_INET_ATON
 int inet_aton(const char *cp, struct in_addr *addr)
 {
 	addr->s_addr = inet_addr(cp);
@@ -57,7 +57,7 @@ int inet_aton(const char *cp, struct in_addr *addr)
 }
 #endif
 
-#ifndef HAVE_GETUTENT
+#if !HAVE_GETUTENT
 
 static int utent_fd = -1;
 
@@ -67,15 +67,22 @@ static int utent_fd = -1;
 
 struct utmp *getutent(void)
 {
-	static utmp ut;
+	static struct utmp ut;
 
 	if (utent_fd == -1) {
 		utent_fd = open(_PATH_UTMP, O_RDONLY | O_NOCTTY);
 	}
 	if (utent_fd == -1)
 		return NULL;
-	read(utent_fd, &ut, sizeof(ut));
-	return &ut;
+	rc = read(utent_fd, &ut, sizeof(ut));
+	if (rc <= 0) {
+		close(utent_fd);
+		utent_fd = -1;
+		return NULL;
+	}
+	else {
+		return &ut;
+	}
 }
 
 void endutent(void)
